@@ -16,9 +16,9 @@ class DefocusAnalyzeResult:
     snapshot_file_id: str
     snapshot_done_at: float
     reference_image_file_ids: list[str]
-    detector_requests: list[dict[Any, Any]]
-    detector_results: list[dict[Any, Any]]
-    comparison_settings: dict[str, Any]
+    detector_requests: list[dict[str, str | float | bool | int]]
+    detector_results: list[dict[str, str | float | bool | int]]
+    comparison_settings: dict[str, str | float]
     comparison_results: list[float]
     result: float
     analyzed_at: float
