@@ -11,7 +11,7 @@ from dataclasses import dataclass
 
 @dataclass
 class DefocusSettings:
-    rtsp_url: str
+    stream_url: str
     freq_diff_threshold: float
     created_at: float | None = None
     updated_at: float | None = None
